#!/usr/bin/env node
'use strict'

const request   = require('superagent');
const glob      = require('glob')
const meow      = require('meow')
const path      = require('path')

const cli = meow(`
  Usage
    $ subtask <email> <user_id> <project_key> <parent_key> <list_to_assign> <assignee_name>
`
)

if (cli.input.length < 5) {
  console.error('Missing: file or pattern.')
  cli.showHelp(1)
}

glob( cli.input[0] || '' , async (error, data) => {

  const email           = cli.input[0]
  const password        = cli.input[1]
  const project_key     = cli.input[2]
  const parent_key      = cli.input[3]
  let   list_to_assign  = cli.input[4]
  const assignee_name   = cli.input[5]

  const subtasks       = {
    ms              : require('./subtasks/microservices').list,
    bff             : require('./subtasks/bff').list,
    ta              : require('./subtasks/technical_analysis').list,
  }

  const credentials = {
    email           : email,
    password        : password,
  }

  const options     = {
    project_key     : project_key,
    parent_key      : parent_key,
    assignee_name   : assignee_name,
    summary         : '',
    description     : '',
  }

  list_to_assign   = subtasks[list_to_assign]

  function create_subtask(options) {
      let request_data = {
          "fields": {
              "project": {
                  "key": options.project_key
              },
              "parent": {
                  "key": options.parent_key
              },
              "summary": options.summary,
              "description": options.description,
              "issuetype": {
                  "name": "Subtarea"
              },
              "assignee": {
                  "name": options.assignee_name
              }
          }
      };

      console.log('Creating task: ' + options.summary);

      const jira_api_url = 'https://naranja.atlassian.net/rest/api/2/issue';

      const res = request.post( jira_api_url )
          .auth(credentials.email, credentials.password)
          .set('Content-Type', 'application/json; charset=utf-8')
          .set('Accept', 'application/json; charset=utf-8')
          .send(request_data)

      return res;
  }

  for (let index = 0; index < list_to_assign.length; index++) {
    options.summary       = list_to_assign[index].summary;
    options.description   = list_to_assign[index].description;
    options.assignee_name = list_to_assign[index].assignee_name;
    let response = await create_subtask(options, credentials);
    console.log(response.body)
  }

})
